@@ -4,7 +4,7 @@ switch ($messaggio) {
 
 case "Database aggiornato alla versione":  	$messaggio = "Datenbank aktualisiert zu Version"; break;
 case "Niente da aggiornare":  			$messaggio = "Nichts zu aktualisieren"; break;
-case "Vai al men principale":  		$messaggio = "Zum Hauptmen&uuml;"; break;
+case "Vai al menù principale":  		$messaggio = "Zum Hauptmen&uuml;"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
@@ -12,4 +12,4 @@ case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
+?>
\ No newline at end of file
