@@ -6,7 +6,7 @@ case "situazione alle":  			$messaggio = "Situation am"; break;
 case "del":  					$messaggio = "vom"; break;
 case "Tabella prenotazioni del":  		$messaggio = "Reservierungstabelle von"; break;
 case "ERRORE":  				$messaggio = "FEHLER"; break;
-case "Torna al men principale":  		$messaggio = "Hauptmen&uuml;"; break;
+case "Torna al menù principale":  		$messaggio = "Hauptmen&uuml;"; break;
 case "Visualizza la tabella per la stampa":  	$messaggio = "Druckbare Version anzeigen"; break;
 case "Visualizza la tabella con i giorni":  	$messaggio = "Tabelle mit Tagen anzeigen"; break;
 case "":  		$messaggio = ""; break;
@@ -15,4 +15,4 @@ case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
+?>
\ No newline at end of file
