@@ -6,7 +6,7 @@ case "situazione alle":  			$messaggio = "Situation am"; break;
 case "del":  					$messaggio = "vom"; break;
 case "Tabella prenotazioni del":  		$messaggio = "Reservierungstabelle von"; break;
 case "ERRORE":  				$messaggio = "FEHLER"; break;
-case "Torna al men principale":  		$messaggio = "Hauptmen&uuml;"; break;
+case "Torna al menù principale":  		$messaggio = "Hauptmen&uuml;"; break;
 case "Visualizza la tabella normale":  		$messaggio = "Normale Tabelle anzeigen"; break;
 case "Visualizza tutti i mesi":  		$messaggio = "Alle Monate anzeigen"; break;
 case "":  		$messaggio = ""; break;
@@ -17,4 +17,4 @@ case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
+?>
\ No newline at end of file
